@@ -147,12 +147,11 @@ MainWindow::MainWindow(QWidget *parent)
     orientationChanged();
 
     //Show first launch msg
-    if (settings->value("firstLaunch", "") != APP_VER)
+    if (settings->value("firstLaunch", "") != APP_VER && APP_FIRSTLAUNCH)
     {
         QMessageBox::about(this,
                            tr("Welcome to a new version of fahrplan this has changed"),
-                           tr("- bugfixes for 131500.com.au backend\n- support for portrait mode")
-                           );
+                           tr(""));
 
         settings->setValue("firstLaunch", APP_VER);
     }
