@@ -45,6 +45,8 @@ ResultInfo parserMobileBahnDe::parseJourneyData(QByteArray data)
     ahrefReg.setMinimal(true);
     element.replace(ahrefReg, "");
 
+    element.replace("<img src=\"/v/760/img/achtung_rot_16x16.gif\" />", "<img src=\"/v/760/img/achtung_rot_16x16.gif\" />" + tr("Warning"));
+
     readBuffer.setData(element.toAscii());
     readBuffer.open(QIODevice::ReadOnly);
 
@@ -249,6 +251,7 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
                 qDebug() << "parserMobileBahnDe::getJourneyDetailsData - Query 3 Failed";
             }
 
+
             /*
             qDebug() <<num;
             qDebug() <<element;
@@ -344,6 +347,43 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
         }
     }
 
+    regexp = QRegExp("<div class=\"red bold\">(.*)</div>");
+    regexp.setMinimal(true);
+    regexp.indexIn(xhtml);
+
+    if (regexp.cap(1).trimmed() != "") {
+        QBuffer readBuffer;
+        QString element = "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<body>\n" + regexp.cap(1) + "\n</body>\n</html>\n";
+
+        //Remove misformed html
+        QRegExp ahrefReg = QRegExp("<a(.*)>");
+        ahrefReg.setMinimal(true);
+        element.replace(ahrefReg, "");
+        element.replace("&nbsp;", " ");
+        ahrefReg = QRegExp("</a>");
+        ahrefReg.setMinimal(true);
+        element.replace(ahrefReg, "");
+        element.replace("&nbsp;", " ");
+
+        readBuffer.setData(element.toAscii());
+        readBuffer.open(QIODevice::ReadOnly);
+
+        QXmlQuery query;
+        query.bindVariable("path", &readBuffer);
+        query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/string()");
+
+        QStringList errormsgsResults;
+        if (!query.evaluateTo(&errormsgsResults))
+        {
+            qDebug() << "parserMobileBahnDe::getJourneyDetailsData - Query 4 Failed";
+        }
+
+        if (result.info != "") {
+            result.info += "<br>";
+        }
+        result.info += errormsgsResults.join("").trimmed();
+    }
+
     return result;
 }
 
@@ -420,8 +460,6 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
 
     filebuffer->close();
 
-    //qDebug() <<filebuffer->buffer();
-
     QString element = filebuffer->buffer();
 
     //Remove misformed html
@@ -505,7 +543,7 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
         {
             for (int i = 0; i < departureResult.count(); i++)
             {
-                if ((QString)departureResult[i] == destinationStation)
+                if ((QString)departureResult[i].trimmed() == destinationStation.trimmed())
                 {
                     destinationStationId = departureResultIds[i];
                 }
@@ -519,7 +557,7 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
         {
             for (int i = 0; i < arrivalResult.count(); i++)
             {
-                if ((QString)arrivalResult[i] == arrivalStation)
+                if ((QString)arrivalResult[i].trimmed() == arrivalStation.trimmed())
                 {
                     arrivalStationId = arrivalResultIds[i];
                 }
