@@ -30,6 +30,7 @@
 #include <backupgpsopenstreetmap.h>
 #include "fahrplanutils.h"
 #include "parser_abstract.h"
+#include "qvaluebutton.h"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -39,7 +40,7 @@ class selectStationDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit selectStationDialog(QMaemo5ValueButton *sender, QGeoPositionInfo *position, parserAbstract *mainBackendParser, QSettings *mainSettings);
+    explicit selectStationDialog(QValueButton *sender, QGeoPositionInfo *position, parserAbstract *mainBackendParser, QSettings *mainSettings);
 
 signals:
 
@@ -47,13 +48,14 @@ public slots:
     void searchButtonClicked(bool checked);
     void gpsButtonClicked(bool checked);
     void stationSelected(QString value);
+    void orientationChanged();
 
 private:
     QComboBox   *searchboxCombo;
     QLineEdit   *searchboxText;
     QPushButton *gpsButton;
     QPushButton *searchButton;
-    QMaemo5ValueButton *mainSender;
+    QValueButton *mainSender;
     QGeoPositionInfo *myPositionInfo;
     QSettings          *settings;
 
